@@ -23,7 +23,7 @@ import os
 from util import logError, m18n, m18nc, isAlive, logWarning
 from common import WINDS, LIGHTSOURCES, InternalParameters, Preferences
 import cgitb, tempfile, webbrowser
-from twisted.internet.defer import succeed
+from twisted.internet.defer import succeed, fail
 from twisted.python.failure import Failure
 
 class MyHook(cgitb.Hook):
@@ -408,10 +408,11 @@ class VisiblePlayer(Player):
 
     def popupMsg(self, msg):
         """shows a yellow message from player"""
-        self.speak(msg.lower())
-        yellow = self.front.message
-        yellow.setText('  '.join([unicode(yellow.msg), m18nc('kajongg', msg)]))
-        yellow.setVisible(True)
+        if msg != 'No Claim':
+            self.speak(msg.lower())
+            yellow = self.front.message
+            yellow.setText('  '.join([unicode(yellow.msg), m18nc('kajongg', msg)]))
+            yellow.setVisible(True)
 
     def hidePopup(self):
         """hide the yellow message from player"""
@@ -616,7 +617,7 @@ class PlayField(KXmlGuiWindow):
                 return self.abortGame()
             else:
                 self.actionAutoPlay.setChecked(demoMode)
-                return succeed(None) # just continue
+                return fail(None) # just continue
         if not self.game:
             self.startingGame = False
             return succeed(None)
